@@ -20,7 +20,7 @@ import os
 
 
 # Version
-VERSION = "1.6.0"
+VERSION = "1.7.0"
 
 # Utilities
 SUDO = "/usr/bin/sudo"
@@ -81,7 +81,7 @@ def cidr_from_netstat_dst(target):
 
 # Convert hexadecimal netmask in prefix length
 def netmask_to_length(mask):
-    return int(mask, 16).bit_count()
+    return bin(int(mask, 16)).count("1")
 
 
 def any_startswith(words, test):
@@ -161,7 +161,15 @@ COLOR_INET6 = 3
 COLOR_OPERSTATE_UP = 4
 COLOR_OPERSTATE_DOWN = 5
 COLOR_NONE = 6
-_COLOR_ATTR = [COLOR_IFNAME, COLOR_MAC, COLOR_INET, COLOR_INET6, COLOR_OPERSTATE_UP, COLOR_OPERSTATE_DOWN, COLOR_NONE]
+_COLOR_ATTR = [
+    COLOR_IFNAME,
+    COLOR_MAC,
+    COLOR_INET,
+    COLOR_INET6,
+    COLOR_OPERSTATE_UP,
+    COLOR_OPERSTATE_DOWN,
+    COLOR_NONE,
+]
 
 
 # light background
@@ -173,8 +181,8 @@ _ATTR_COLORS_LIGHT = [
     C_BLUE,
     C_GREEN,
     C_RED,
-    C_CLEAR
-    ]
+    C_CLEAR,
+]
 
 
 # dark background
@@ -186,8 +194,8 @@ _ATTR_COLORS_DARK = [
     C_BOLD_BLUE,
     C_BOLD_GREEN,
     C_BOLD_RED,
-    C_CLEAR
-    ]
+    C_CLEAR,
+]
 
 
 def get_color_scheme(color_mode, json):
@@ -214,7 +222,7 @@ def get_color_scheme(color_mode, json):
         c = p.split(";")[-1]
         if c.isnumeric():
             c = int(c)
-            if (c >= 0 and c <=6) or c == 8:
+            if (c >= 0 and c <= 6) or c == 8:
                 return "dark"
     return "light"
 
@@ -242,7 +250,7 @@ def _check_enable_color(color, json):
         return True
 
     # Following code implements auto mode
-    if os.getenv('NO_COLOR') is not None:
+    if os.getenv("NO_COLOR") is not None:
         return False
 
     # Not supported if not attached to terminal
@@ -251,21 +259,34 @@ def _check_enable_color(color, json):
 
     try:
         # Use tput to check color support
-        colors = int(subprocess.check_output(['tput', 'colors'],
-                                          stderr=subprocess.DEVNULL).decode().strip())
+        colors = int(
+            subprocess.check_output(
+                ["tput", "colors"], stderr=subprocess.DEVNULL
+            )
+            .decode()
+            .strip()
+        )
         return colors >= 8
     except (subprocess.CalledProcessError, ValueError):
         # If tput fails or returns invalid output, fall back to TERM check
-        term = os.getenv('TERM', '')
-        if term == 'dumb':
+        term = os.getenv("TERM", "")
+        if term == "dumb":
             return False
 
-        color_terms = ['xterm', 'xterm-color', 'xterm-256color', 'linux',
-                      'screen', 'screen-256color', 'vt100', 'rxvt']
+        color_terms = [
+            "xterm",
+            "xterm-color",
+            "xterm-256color",
+            "linux",
+            "screen",
+            "screen-256color",
+            "vt100",
+            "rxvt",
+        ]
         return any(term.startswith(t) for t in color_terms)
 
 
-def colorize(scheme, attr, text):
+def colorize(scheme, attr, text, ljust=0):
     """
     Wraps text with color according to scheme and attribute type.
 
@@ -273,12 +294,13 @@ def colorize(scheme, attr, text):
         scheme (str): "none", "dark" or "light"
         attr (str): Attribute type, see COLOR_ATTR
         text (str): Text to colorize
+        ljust (int): Left-justified space padding length
 
     Returns:
         str: Colorized text
     """
     if scheme == "none" or scheme is None:
-        return text
+        return text.ljust(ljust)
 
     if attr not in _COLOR_ATTR:
         raise ValueError("Invalid color attribute")
@@ -288,40 +310,40 @@ def colorize(scheme, attr, text):
     else:
         color = _ATTR_COLORS_DARK[attr]
 
-    return f"{color}{text}{C_CLEAR}"
+    return f"{color}{text}{C_CLEAR}" + (" " * max(0, ljust - len(text)))
 
 
-def colorize_ifname(scheme, ifname):
-    return colorize(scheme, COLOR_IFNAME, ifname)
+def colorize_ifname(scheme, ifname, ljust=0):
+    return colorize(scheme, COLOR_IFNAME, ifname, ljust)
 
 
-def colorize_mac(scheme, mac):
-    return colorize(scheme, COLOR_MAC, mac)
+def colorize_mac(scheme, mac, ljust=0):
+    return colorize(scheme, COLOR_MAC, mac, ljust=0)
 
 
-def colorize_inet(scheme, af, inet):
+def colorize_inet(scheme, af, inet, ljust=0):
     """
     Matches behavior of ifa_family_color() for addresses.
     But skips coloring when inet is default.
     """
     if inet == "default":
-        return inet
+        return str(inet).ljust(ljust)
 
     if af == "inet":
-        return colorize(scheme, COLOR_INET, inet)
+        return colorize(scheme, COLOR_INET, inet, ljust)
     elif af == "inet6":
-        return colorize(scheme, COLOR_INET6, inet)
+        return colorize(scheme, COLOR_INET6, inet, ljust)
     else:
-        return inet
+        return str(inet).ljust(ljust)
 
 
-def colorize_op_state(scheme, state):
+def colorize_op_state(scheme, state, ljust=0):
     """
     Matches behavior of oper_state_color() for states.
     """
     if state == "UP":
-        return colorize(scheme, COLOR_OPERSTATE_UP, state)
+        return colorize(scheme, COLOR_OPERSTATE_UP, state, ljust)
     elif state == "DOWN":
-        return colorize(scheme, COLOR_OPERSTATE_DOWN, state)
+        return colorize(scheme, COLOR_OPERSTATE_DOWN, state, ljust)
     else:
-        return state
+        return str(state).ljust(ljust)
