@@ -5,6 +5,7 @@ rundir=$(cd -P -- "$(dirname -- "$0")" && printf '%s\n' "$(pwd -P)")
 
 ip_cmd="$rundir"/../src/ip.py
 bridge_cmd="$rundir"/../src/bridge.py
+ss_cmd="$rundir"/../src/ss.py
 ip_prefix=192.0.2
 ip_dest=$ip_prefix.99/32
 ip_via=$ip_prefix.98
@@ -13,9 +14,11 @@ ip_via=$ip_prefix.98
 
 $ip_cmd -V
 $bridge_cmd -V
+$ss_cmd -V
 
 $ip_cmd --V
 $bridge_cmd --V
+$ss_cmd --V
 
 $ip_cmd -color -V
 $ip_cmd -color=always -V
@@ -27,17 +30,26 @@ $bridge_cmd -color=always -V
 $bridge_cmd -color=auto -V
 $bridge_cmd -color=never -V
 
+$ss_cmd -color -V
+$ss_cmd -color=always -V
+$ss_cmd -color=auto -V
+$ss_cmd -color=never -V
+
 ! $ip_cmd help
 ! $bridge_cmd help
+! $ss_cmd help
 
 $ip_cmd help 2>&1 >/dev/null | grep "Usage: ip "
 $bridge_cmd help 2>&1 >/dev/null | grep "Usage: bridge "
+$ss_cmd -h 2>&1 >/dev/null | grep "Usage: ss "
 
 ! $ip_cmd asdf sh
 ! $bridge_cmd asdf sh
+! $ss_cmd asdf sh
 
 ! $ip_cmd -M route sh
 ! $bridge_cmd -N link sh
+! $ss_cmd -X socket sh
 
 # route
 
@@ -112,6 +124,8 @@ $ip_cmd address show
 
 $ip_cmd -c address show
 
+$ip_cmd -o address show
+
 $ip_cmd -j addr show | tee | perl -MJSON -e 'decode_json(<STDIN>)'
 
 $ip_cmd -4 addr show
@@ -132,6 +146,29 @@ $ip_cmd a s
 
 ! $ip_cmd addr asdf
 
+## brief format tests
+
+# Test basic -br addr show
+$ip_cmd -br addr show | grep -E "^lo[0-9]* +[A-Z]+ +"
+
+# Test -br a shorthand
+$ip_cmd -br a | grep -E "^lo[0-9]* +[A-Z]+ +"
+
+# Test -br with specific device
+$ip_cmd -br addr show dev lo0 | grep -E "^lo0 +[A-Z]+ +"
+
+# Test -br with -4 (IPv4 only)
+$ip_cmd -4 -br addr show | grep -E "^lo[0-9]* +[A-Z]+ +" | grep "127.0.0.1"
+
+# Test -br with -6 (IPv6 only)
+$ip_cmd -6 -br addr show | grep -E "^lo[0-9]* +[A-Z]+ +" | grep "::1"
+
+# Test -br with -j (JSON output should override brief)
+$ip_cmd -br -j addr show | perl -MJSON -e 'decode_json(<STDIN>)'
+
+# Test order: -br before command
+$ip_cmd -br addr show | grep -E "^lo[0-9]* +[A-Z]+ +"
+
 
 # link
 
@@ -141,6 +178,8 @@ $ip_cmd lin hel 2>&1 >/dev/null | grep "Usage: ip link"
 
 $ip_cmd -c link show
 
+$ip_cmd -o link show
+
 $ip_cmd link show | grep mtu
 
 $ip_cmd -j link show | tee | perl -MJSON -e 'decode_json(<STDIN>)'
@@ -157,6 +196,20 @@ $ip_cmd l s | grep mtu
 
 ! $ip_cmd link asdf
 
+## link brief format tests
+
+# Test basic -br link show
+$ip_cmd -br link show | grep -E "^lo[0-9]* +[A-Z]+ +"
+
+# Test -br l shorthand
+$ip_cmd -br l | grep -E "^lo[0-9]* +[A-Z]+ +"
+
+# Test -br with specific device
+$ip_cmd -br link show lo0 | grep -E "^lo0 +[A-Z]+ +"
+
+# Test -br with -j (JSON output should override brief)
+$ip_cmd -br -j link show | perl -MJSON -e 'decode_json(<STDIN>)'
+
 # neigh
 
 $ip_cmd nei help 2>&1 >/dev/null | grep "Usage: ip neighbour"
@@ -181,4 +234,32 @@ $bridge_cmd link show
 
 $bridge_cmd -c link show
 
+$bridge_cmd -o link show
+
+# ss
+
+$ss_cmd
+
+$ss_cmd -c
+
+$ss_cmd -j | tee | perl -MJSON -e 'decode_json(<STDIN>)'
+
+$ss_cmd -4
+
+$ss_cmd -6
+
+$ss_cmd -t
+
+$ss_cmd -u
+
+$ss_cmd -l
+
+$ss_cmd -a
+
+$ss_cmd -s
+
+$ss_cmd -j -p | grep '"netid"'
+
+! $ss_cmd asdf
+
 echo "Tests passed!!"
